@@ -39,8 +39,8 @@ Version 1.0 (from the 23.02.2012)
 
 """
 
-from stream import *
-from transfer import *
+from magpy.stream import *
+from magpy.transfer import *
 
 MAGPY_SUPPORTED_ABSOLUTES_FORMATS = ['MAGPYABS','MAGPYNEWABS','AUTODIF','UNKNOWN']
 ABSKEYLIST = ['time', 'hc', 'vc', 'res', 'f', 'mu', 'md', 'expectedmire', 'varx', 'vary', 'varz', 'varf', 'var1', 'var2']
@@ -1032,7 +1032,7 @@ class AbsoluteData(object):
 #  Now import the format libraries
 #
 
-from lib.magpy_absformats import *
+from magpy.lib.magpy_absformats import *
 
 
 def _logfile_len(fname, logfilter):
