@@ -5,7 +5,7 @@ Written by Roman Leonhardt June 2012
 - contains test and read function, toDo: write function
 """
 
-from absolutes import *
+from magpy.absolutes import *
 
 
 def isMAGPYABS(filename):
